@@ -18,7 +18,7 @@
 
 #include <KLocalizedString>
 #include <KNotification>
-#include <KWindowSystem>
+#include <KX11Extras>
 
 RequestPin::RequestPin(BluezQt::DevicePtr device, bool numeric, QObject *parent)
     : QObject(parent)
@@ -87,10 +87,11 @@ void RequestPin::introducePin()
     connect(m_dialogWidget->buttonBox, &QDialogButtonBox::accepted, dialog, &QDialog::accept);
     connect(m_dialogWidget->buttonBox, &QDialogButtonBox::rejected, dialog, &QDialog::reject);
 
+    dialog->setWindowFlags(Qt::WindowStaysOnTopHint);
+
     dialog->show();
 
-    KWindowSystem::setState(dialog->winId(), NET::KeepAbove);
-    KWindowSystem::forceActiveWindow(dialog->winId());
+    KX11Extras::forceActiveWindow(dialog->winId());
 }
 
 void RequestPin::checkPin(const QString &pin)
